@@ -205,7 +205,7 @@ class Client(Callbacks, SocketHandler):
 
         response = requests.post(f"{self.api}/g/s/auth/login", headers=self.parse_headers(data=data), data=data, proxies=self.proxies, verify=self.certificatePath)
         #print(self.parse_headers(data=data))
-        #self.run_socket()
+        self.run_socket()
         if response.status_code != 200: return exceptions.CheckException(json.loads(response.text))
 
         else:
@@ -216,7 +216,7 @@ class Client(Callbacks, SocketHandler):
             self.account: objects.UserProfile = objects.UserProfile(self.json["account"]).UserProfile
             self.profile: objects.UserProfile = objects.UserProfile(self.json["userProfile"]).UserProfile
             headers.sid = self.sid
-            #self.start()
+            self.start()
             return response.status_code
 
     def register(self, nickname: str, email: str, password: str, verificationCode: str, deviceId: str = device.device_id):
